from typing import List, Optional
from pydantic import BaseModel, Field
from datetime import datetime

from app.models.order import OrderStatus


# OrderItem schemas
class OrderItemBase(BaseModel):
    product_id: int
    quantity: int = Field(..., gt=0)


class OrderItemCreate(OrderItemBase):
    pass


class OrderItemUpdate(OrderItemBase):
    pass


class OrderItemInDBBase(OrderItemBase):
    id: int
    order_id: int
    unit_price: float

    class Config:
        from_attributes = True


class OrderItem(OrderItemInDBBase):
    pass


# Order schemas
class OrderBase(BaseModel):
    user_id: Optional[int] = None
    shipping_address: Optional[str] = None
    status: Optional[OrderStatus] = None


class OrderCreate(OrderBase):
    user_id: int
    shipping_address: str
    items: List[OrderItemCreate]


class OrderUpdate(OrderBase):
    status: Optional[OrderStatus] = None


class OrderInDBBase(OrderBase):
    id: int
    user_id: int
    total_amount: float
    status: OrderStatus
    shipping_address: str
    created_at: datetime
    updated_at: Optional[datetime] = None

    class Config:
        from_attributes = True


class Order(OrderInDBBase):
    items: List[OrderItem]


class OrderInDB(OrderInDBBase):
    pass